FetchCubit<F> class

Constructors

FetchCubit({String? timeoutMessage, String? unexpectedExceptionMessage, Stream<F>? dataUpdatedStream})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state FetchState<F>
The current state.
no setterinherited
stream Stream<FetchState<F>>
The current stream of states.
no setterinherited
timeoutMessage String?
final
unexpectedExceptionMessage String?
final

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
close() Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
emit(FetchState<F> state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
fetch({required DataFetcher<F> dataFetcher, Duration timeout = const Duration(seconds: 10)}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<FetchState<F>> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
refresh({required DataFetcher<F> dataFetcher, Duration timeout = const Duration(seconds: 10)}) Future<void>
refreshWithoutFetch({required F data}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited