SubmitCubit<F> class

Constructors

SubmitCubit({String? timeoutMessage, String? unexpectedExceptionMessage, String? technicalErrorMessage, FetchCubit<F>? fetchCubit, DataFetcher<F>? dataFetcher})

Properties

dataFetcher DataFetcher<F>?
final
fetchCubit FetchCubit<F>?
final
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state SubmitState
The current state.
no setterinherited
stream Stream<SubmitState>
The current stream of states.
no setterinherited
technicalErrorMessage String?
final
timeoutMessage String?
final
unexpectedExceptionMessage String?
final

Methods

addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
close() Future<void>
Closes the instance. This method should be called when the instance is no longer needed. Once close is called, the instance can no longer be used.
inherited
emit(SubmitState state) → void
Updates the state to the provided state. emit does nothing if the state being emitted is equal to the current state.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange(Change<SubmitState> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
submit({required DataSubmitter<void> dataSubmitter, DataOnResponseReceived<void>? onResponseReceived, Duration timeout = const Duration(seconds: 10)}) Future<void>
submitAndFetch({required DataSubmitter<void> dataSubmitter, Duration timeout = const Duration(seconds: 10)}) Future<void>
submitAndRefresh({required DataSubmitter<F> dataSubmitter, Duration timeout = const Duration(seconds: 10)}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited