SubmitPage class
A simple page focused on form submission.
This page provides:
- A clean layout for forms
- Built-in submission state handling
- Loading indicator during submission
- Automatic scroll behavior
- Safe area and padding management
Ideal for simple forms that don't require initial data fetching.
Example:
SubmitPage<LoginData>(
pageTitle: Text('Login'),
child: LoginForm(),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SubmitPage
Constructors
-
SubmitPage({required SubmitWidgetBuilder builder, EdgeInsets? padding, AppBarBuilder? appBarBuilder, PageElementWidgetBuilder<
void> ? floatingActionButtonBuilder, PageElementWidgetBuilder<void> ? stickyBottomBuilder, String? timeoutError, String? unexpectedError, String? technicalError, bool useCustomScrollView = true, Key? key}) -
const
Properties
- appBarBuilder → AppBarBuilder?
-
final
- builder → SubmitWidgetBuilder
-
final
-
floatingActionButtonBuilder
→ PageElementWidgetBuilder<
void> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → EdgeInsets?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stickyBottomBuilder
→ PageElementWidgetBuilder<
void> ? -
final
- technicalError → String?
-
final
- timeoutError → String?
-
final
- unexpectedError → String?
-
final
- useCustomScrollView → bool
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited