submitLoader property
Loader shown while a submit triggered from this page is in flight.
Falls back to FluttyStateConfig.defaultSubmitLoader then to the built-in overlay.
Implementation
final Widget? submitLoader;
Loader shown while a submit triggered from this page is in flight.
Falls back to FluttyStateConfig.defaultSubmitLoader then to the built-in overlay.
final Widget? submitLoader;