FetchAndSubmitPage<F> class
A page that combines data fetching and form submission capabilities.
This page will:
- Automatically fetch data on initialization using dataFetcher
- Display a loading indicator while fetching
- Show error state if fetch fails
- Allow manual refresh (pull-to-refresh and refresh button on Windows)
- Handle form submissions with loading state
- Maintain static content during loading states if staticChildBuilder is provided
Example:
FetchAndSubmitPage<UserData>(
pageTitle: Text('User Profile'),
dataFetcher: () => getUserData(),
builder: (data, context) => UserForm(data: data),
staticChildBuilder: (child, context) => Column(children: [Banner(), child]),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FetchAndSubmitPage
Constructors
-
FetchAndSubmitPage({required SuccessWidgetBuilder<
F> builder, required DataFetcher<F> dataFetcher, Stream<F> ? dataUpdatedStream, Widget? loader, Widget? loadingFailed, EdgeInsets? padding, AppBarBuilder<F> ? appBarBuilder, StaticChildBuilder<F> ? staticChildBuilder, PageElementWidgetBuilder<F> ? floatingActionButtonBuilder, PageElementWidgetBuilder<F> ? stickyBottomBuilder, String? timeoutError, String? unexpectedError, String? technicalError, Key? key}) -
const
Properties
-
appBarBuilder
→ AppBarBuilder<
F> ? -
final
-
builder
→ SuccessWidgetBuilder<
F> -
final
-
dataFetcher
→ DataFetcher<
F> -
final
-
dataUpdatedStream
→ Stream<
F> ? -
final
-
floatingActionButtonBuilder
→ PageElementWidgetBuilder<
F> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- loader → Widget?
-
final
- loadingFailed → Widget?
-
final
- padding → EdgeInsets?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
staticChildBuilder
→ StaticChildBuilder<
F> ? -
final
-
stickyBottomBuilder
→ PageElementWidgetBuilder<
F> ? -
final
- technicalError → String?
-
final
- timeoutError → String?
-
final
- unexpectedError → String?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited